@@ -48,6 +48,17 @@ optional if the key name is a simple string:
 >>> x = 7
 >>> catcher('x')
 7
+
+A special singleton global, "TC." is available to streamline this further.
+Anything assiged to TC, by attribute or item, is thrown().  Anything
+accessed via TC, by attribute or item, is catch()'ed:
+
+>>> def catcher(name):
+...     print TC[name]
+...
+>>> TC.x = 5
+>>> catcher('x')
+5
 '''
 
 from __version__ import *
@@ -108,3 +119,21 @@ class BWThrowable(object):
     def __exit__(self, *_args):
         pass
 
+class BWThrowCatch(object):
+    def __getitem__(self, key):
+        if isinstance(key, type):
+            return key.catch()
+        else:
+            return catch(key)
+
+    def __setitem__(self, key, value):
+        throw(key, value, 1)
+
+    def __getattr__(self, name):
+        return catch(name)
+
+    def __setattr__(self, name, value):
+        throw(name, value, 1)
+
+TC = BWThrowCatch()
+
